@@ -13,11 +13,9 @@
 # under the License.
 
 import abc
-import six
 
 
-@six.add_metaclass(abc.ABCMeta)
-class MachineLearningBase(object):
+class MachineLearningBase(object, metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def process_event(self, data, event_type):
